@@ -1,3 +1,3 @@
 from .parser import Parser, ParseError, UnifyError
-from .grammar import Grammar, GrammarError, format_feat
+from .grammar import Grammar, GrammarError, format_feat, Trie, Rule
 from .tree import Tree
